@@ -1586,7 +1586,9 @@ class VariableClUpdateKernelPkg(ReadonlyVariable):
     def get(self):
         src_path = self.Get('cl_update_kernel_src_path')
         if src_path:
-            return
+            qfile = process('/usr/bin/qfile', '-vqC', src_path)
+            if qfile.success():
+                return qfile.read().strip()
         return ""
 
 
